class DatabaseSwitcher
  attr_reader :database_name, :config_file_path

  def initialize(database_name, config_file_path: 'config/database-switcher.yml')
    @database_name = database_name
    @config_file_path = config_file_path
    @main_db_params = ActiveRecord::Base.configurations[Rails.env] 
  end

  def perform(&block)
    switch_db_connection
    return_value = block.call
    restore_main_db_connection
    return_value
  end

  private

  def switch_db_connection
    ActiveRecord::Base.establish_connection(target_db_params)
  end

  def target_db_params
    config[database_name]    
  end

  def config
    @config ||= YAML::load(config_file)
  end

  def config_file
    @config_file ||= File.read(config_file_path)
  end

  def restore_main_db_connection
    ActiveRecord::Base.establish_connection(@main_db_params)
  end
end
